==> buildbot_3.10.1.orig.tar.gz: buildbot-3.10.1/www/react-console_view/setup.py <==
#!/usr/bin/env python
#
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

try:
    from buildbot_pkg import setup_www_plugin
except ImportError:
    import sys
    print('Please install buildbot_pkg module in order to install that '
          'package, or use the pre-build .whl modules available on pypi',
          file=sys.stderr)
    sys.exit(1)

setup_www_plugin(
    name='buildbot-react-console-view',
    description='Buildbot Console View plugin (React)',
    author='Pierre Tardy',
    author_email='tardyp@gmail.com',
    url='http://buildbot.net/',
    packages=['buildbot_react_console_view'],
    package_data={
        '': [
            'VERSION',
            'static/*',
            'static/assets/*',
        ]
    },
    entry_points="""
        [buildbot.www]
        react_console_view = buildbot_react_console_view:ep
    """,
    classifiers=[
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)'
    ],
)

==> buildbot_4.0.2.orig.tar.gz: buildbot-4.0.2/www/react-console_view/setup.py <==
#!/usr/bin/env python
#
# This file is part of Buildbot.  Buildbot is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Buildbot Team Members

try:
    from buildbot_pkg import setup_www_plugin
except ImportError:
    import sys

    print(
        'Please install buildbot_pkg module in order to install that '
        'package, or use the pre-build .whl modules available on pypi',
        file=sys.stderr,
    )
    sys.exit(1)

setup_www_plugin(
    name='buildbot-react-console-view',
    description='Buildbot Console View plugin (React)',
    author='Pierre Tardy',
    author_email='tardyp@gmail.com',
    url='http://buildbot.net/',
    packages=['buildbot_react_console_view'],
    package_data={
        '': [
            'VERSION',
            'static/*',
            'static/assets/*',
        ]
    },
    entry_points="""
        [buildbot.www]
        react_console_view = buildbot_react_console_view:ep
    """,
    classifiers=['License :: OSI Approved :: GNU General Public License v2 (GPLv2)'],
)
